@@ -56,7 +56,7 @@ WriteIncludes(FILE *file)
 
 	if (InternalHeaderFileName != strNULL)
 	{
-	    register char *cp;
+	    char *cp;
 
 	    /* Strip any leading path from InternalHeaderFileName. */
 	    cp = strrchr(InternalHeaderFileName, '/');
@@ -70,7 +70,7 @@ WriteIncludes(FILE *file)
 
     if (UserHeaderFileName != strNULL)
     {
-	register char *cp;
+	char *cp;
 
 	/* Strip any leading path from UserHeaderFileName. */
 	cp = strrchr(UserHeaderFileName, '/');
@@ -90,7 +90,9 @@ WriteIncludes(FILE *file)
     fprintf(file, "#include <mach/mig_errors.h>\n");
     fprintf(file, "#include <mach/mig_support.h>\n");
     fprintf(file, "#include <mach/msg_type.h>\n");
-    fprintf(file, "/* LINTLIBRARY */\n");
+    if (IsKernelUser)
+	fprintf(file, "#include <kern/ipc_mig.h>\n");
+    fprintf(file, "#include <stdint.h>\n");
     fprintf(file, "\n");
 }
 
@@ -207,12 +209,12 @@ WriteVarDecls(FILE *file, const routine_t *rt)
     fprintf(file, "\t} Mess;\n");
     fprintf(file, "\n");
 
-    fprintf(file, "\tregister Request *InP = &Mess.In;\n");
+    fprintf(file, "\tRequest *InP = &Mess.In;\n");
     if (!rt->rtOneWay)
-	fprintf(file, "\tregister Reply *OutP = &Mess.Out;\n");
+	fprintf(file, "\tReply *OutP = &Mess.Out;\n");
     fprintf(file, "\n");
 
-    if (!rt->rtOneWay || rt->rtProcedure)
+    if (!rt->rtOneWay)
 	fprintf(file, "\tmach_msg_return_t msg_result;\n");
 
     if (!rt->rtSimpleFixedRequest)
@@ -251,11 +253,9 @@ WriteVarDecls(FILE *file, const routine_t *rt)
 static void
 WriteMsgError(FILE *file, const routine_t *rt, const char *error_msg)
 {
-    if (rt->rtProcedure)
-	fprintf(file, "\t\t{ %s(%s); return; }\n", rt->rtErrorName, error_msg);
-    else if (rt->rtReturn != rt->rtRetCode)
+    if (rt->rtReturn != rt->rtRetCode)
     {
-	fprintf(file, "\t\t{ %s(%s); ", rt->rtErrorName, error_msg);
+	fprintf(file, "\t\t{ (%s); ", error_msg);
 	if (rt->rtNumReplyVar > 0)
 	    fprintf(file, "OutP = &Mess.Out; ");
 	fprintf(file, "return OutP->%s; }\n", rt->rtReturn->argMsgField);
@@ -266,16 +266,12 @@ WriteMsgError(FILE *file, const routine_t *rt, const char *error_msg)
 
 /*************************************************************
  *   Writes the send call when there is to be no subsequent
- *   receive. Called by WriteRoutine for SimpleProcedures
- *   or SimpleRoutines
+ *   receive. Called by WriteRoutine for SimpleRoutines.
  *************************************************************/
 static void
 WriteMsgSend(FILE *file, const routine_t *rt)
 {
-    const char *MsgResult = (rt->rtProcedure)
-			? "msg_result ="
-			: "return";
-
+    const char *MsgResult = "return";
     char SendSize[24];
 
     if (rt->rtNumRequestVar == 0)
@@ -300,12 +296,6 @@ WriteMsgSend(FILE *file, const routine_t *rt)
 		" MACH_PORT_NULL, MACH_MSG_TIMEOUT_NONE, MACH_PORT_NULL);\n"
 		);
     }
-
-    if (rt->rtProcedure)
-    {
-	fprintf(file, "\tif (msg_result != MACH_MSG_SUCCESS)\n");
-	WriteMsgError(file, rt, "msg_result");
-    }
 }
 
 /*************************************************************
@@ -341,7 +331,7 @@ WriteMsgCheckReceive(FILE *file, const routine_t *rt, const char *success)
 /*************************************************************
  *  Writes the rpc call and the code to check for errors.
  *  This is the default code to be generated. Called by WriteRoutine
- *  for all routine types except SimpleProcedure and SimpleRoutine.
+ *  for all routine types except SimpleRoutine.
  *************************************************************/
 static void
 WriteMsgRPC(FILE *file, const routine_t *rt)
@@ -390,10 +380,10 @@ WritePackArgType(FILE *file, const argument_t *arg)
  *  in the request message.
  *************************************************************/
 static void
-WritePackArgValue(FILE *file, register const argument_t *arg)
+WritePackArgValue(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *it = arg->argType;
-    register const char *ref = arg->argByReferenceUser ? "*" : "";
+    const ipc_type_t *it = arg->argType;
+    const char *ref = arg->argByReferenceUser ? "*" : "";
 
     if (it->itInLine && it->itVarArray) {
 
@@ -410,6 +400,11 @@ WritePackArgValue(FILE *file, register const argument_t *arg)
 		arg->argMsgField,
 		arg->argVarName,
 		it->itNumber);
+	    fprintf(file,
+		"\tif (InP->%s < %d) InP->%s += 1;\n",
+		arg->argCount->argMsgField,
+		it->itNumber,
+	        arg->argCount->argMsgField);
 	}
 	else {
 
@@ -418,9 +413,9 @@ WritePackArgValue(FILE *file, register const argument_t *arg)
 	     *	after checking that number of elements doesn`t
 	     *	exceed declared maximum.
 	     */
-	    register const argument_t *count = arg->argCount;
-	    register const char *countRef = count->argByReferenceUser ? "*" :"";
-	    register const ipc_type_t *btype = it->itElement;
+	    const argument_t *count = arg->argCount;
+	    const char *countRef = count->argByReferenceUser ? "*" :"";
+	    const ipc_type_t *btype = it->itElement;
 
 	    /* Note btype->itNumber == count->argMultiplier */
 
@@ -441,9 +436,9 @@ WritePackArgValue(FILE *file, register const argument_t *arg)
 			    arg->argLongForm ? ".msgtl_header" : "",
 			    arg->argDealloc->argByReferenceUser ? "*" : "",
 			    arg->argDealloc->argVarName);
-		fprintf(file, "\t\t*((%s **)InP->%s) = %s%s;\n",
-			FetchUserType(btype),
+		fprintf(file, "\t\tInP->%s%s = %s%s;\n",
 			arg->argMsgField,
+			OOLPostfix,
 			ref, arg->argVarName);
 		if (!arg->argRoutine->rtSimpleFixedRequest)
 		    fprintf(file, "\t\tmsgh_simple = FALSE;\n");
@@ -473,11 +468,11 @@ WritePackArgValue(FILE *file, register const argument_t *arg)
 }
 
 static void
-WriteAdjustMsgSimple(FILE *file, register const argument_t *arg)
+WriteAdjustMsgSimple(FILE *file, const argument_t *arg)
 {
     if (!arg->argRoutine->rtSimpleFixedRequest)
     {
-	register const char *ref = arg->argByReferenceUser ? "*" : "";
+	const char *ref = arg->argByReferenceUser ? "*" : "";
 
 	fprintf(file, "\tif (MACH_MSG_TYPE_PORT_ANY(%s%s))\n",
 		ref, arg->argVarName);
@@ -490,11 +485,11 @@ WriteAdjustMsgSimple(FILE *file, register const argument_t *arg)
  * Calculate the size of a variable-length message field.
  */
 static void
-WriteArgSize(FILE *file, register const argument_t *arg)
+WriteArgSize(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *ptype = arg->argType;
-    register int bsize = ptype->itElement->itTypeSize;
-    register const argument_t *count = arg->argCount;
+    const ipc_type_t *ptype = arg->argType;
+    int bsize = ptype->itElement->itTypeSize;
+    const argument_t *count = arg->argCount;
 
     if (ptype->itIndefinite) {
 	/*
@@ -503,7 +498,7 @@ WriteArgSize(FILE *file, register const argument_t *arg)
 	fprintf(file, "(InP->%s%s.msgt_inline) ? ",
 		arg->argTTName, arg->argLongForm ? ".msgtl_header" : "");
     }
-    if (bsize % 4 != 0)
+    if (bsize % word_size != 0)
 	fprintf(file, "(");
 
     if (bsize > 1)
@@ -519,11 +514,11 @@ WriteArgSize(FILE *file, register const argument_t *arg)
 		count->argVarName);
 
     /*
-     * If the base type size is not a multiple of sizeof(int) [4],
+     * If the base type size is not a multiple of word_size,
      * we have to round up.
      */
-    if (bsize % 4 != 0)
-	fprintf(file, " + 3) & ~3");
+    if (bsize % word_size != 0)
+	fprintf(file, " + %d) & ~%d", word_size - 1, word_size - 1);
 
     if (ptype->itIndefinite) {
 	fprintf(file, " : sizeof(%s *)",
@@ -537,9 +532,9 @@ WriteArgSize(FILE *file, register const argument_t *arg)
  * has more arguments following.
  */
 static void
-WriteAdjustMsgSize(FILE *file, register const argument_t *arg)
+WriteAdjustMsgSize(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *ptype = arg->argType;
+    const ipc_type_t *ptype = arg->argType;
 
     /* There are more In arguments.  We need to adjust msgh_size
        and advance InP, so we save the size of the current field
@@ -568,7 +563,7 @@ WriteAdjustMsgSize(FILE *file, register const argument_t *arg)
  * last argument has been packed.
  */
 static void
-WriteFinishMsgSize(FILE *file, register const argument_t *arg)
+WriteFinishMsgSize(FILE *file, const argument_t *arg)
 {
     /* No more In arguments.  If this is the only variable In
        argument, the previous msgh_size value is the minimum
@@ -588,10 +583,10 @@ WriteFinishMsgSize(FILE *file, register const argument_t *arg)
 }
 
 static void
-WriteInitializeCount(FILE *file, register const argument_t *arg)
+WriteInitializeCount(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *ptype = arg->argCInOut->argParent->argType;
-    register const ipc_type_t *btype = ptype->itElement;
+    const ipc_type_t *ptype = arg->argCInOut->argParent->argType;
+    const ipc_type_t *btype = ptype->itElement;
 
     fprintf(file, "\tif (%s%s < %d)\n",
 	    arg->argByReferenceUser ? "*" : "",
@@ -612,7 +607,7 @@ WriteInitializeCount(FILE *file, register const argument_t *arg)
  * argument into the request message.
  */
 static void
-WritePackArg(FILE *file, register const argument_t *arg)
+WritePackArg(FILE *file, const argument_t *arg)
 {
     if (akCheck(arg->argKind, akbRequest))
 	WritePackArgType(file, arg);
@@ -633,10 +628,10 @@ WritePackArg(FILE *file, register const argument_t *arg)
  * message types.
  */
 static void
-WriteRequestArgs(FILE *file, register const routine_t *rt)
+WriteRequestArgs(FILE *file, const routine_t *rt)
 {
-    register const argument_t *arg;
-    register const argument_t *lastVarArg;
+    const argument_t *arg;
+    const argument_t *lastVarArg;
 
     lastVarArg = argNULL;
     for (arg = rt->rtArgs; arg != argNULL; arg = arg->argNext)
@@ -680,9 +675,9 @@ WriteRequestArgs(FILE *file, register const routine_t *rt)
 static void
 WriteCheckIdentity(FILE *file, const routine_t *rt)
 {
-    fprintf(file, "\tif (OutP->Head.msgh_id != %d) {\n",
+    fprintf(file, "\tif (mig_unlikely (OutP->Head.msgh_id != %d)) {\n",
 	    rt->rtNumber + SubsystemBase + 100);
-    fprintf(file, "\t\tif (OutP->Head.msgh_id == MACH_NOTIFY_SEND_ONCE)\n");
+    fprintf(file, "\t\tif (OutP->Head.msgh_id == MACH_NOTIFY_SEND_ONCE)\n\t");
     WriteMsgError(file, rt, "MIG_SERVER_DIED");
     fprintf(file, "\t\telse {\n");
     fprintf(file, "\t\t\t%smig_dealloc_reply_port(%s);\n\t",
@@ -702,16 +697,17 @@ WriteCheckIdentity(FILE *file, const routine_t *rt)
 	    fprintf(file, "\tmsgh_size = OutP->Head.msgh_size;\n\n");
 
 	fprintf(file,
-	    "\tif ((OutP->Head.msgh_bits & MACH_MSGH_BITS_COMPLEX) ||\n");
+	    "\tif (mig_unlikely ("
+	    "(OutP->Head.msgh_bits & MACH_MSGH_BITS_COMPLEX) ||\n");
 	if (rt->rtNoReplyArgs)
-	    fprintf(file, "\t    (OutP->Head.msgh_size != %d))\n",
+	    fprintf(file, "\t    (OutP->Head.msgh_size != %d)))\n",
 			rt->rtReplySize);
 	else {
 	    fprintf(file, "\t    ((msgh_size %s %d) &&\n",
 		(rt->rtNumReplyVar > 0) ? "<" : "!=",
 		rt->rtReplySize);
 	    fprintf(file, "\t     ((msgh_size != sizeof(mig_reply_header_t)) ||\n");
-	    fprintf(file, "\t      (OutP->RetCode == KERN_SUCCESS))))\n");
+	    fprintf(file, "\t      (OutP->RetCode == KERN_SUCCESS)))))\n");
 	}
     }
     else {
@@ -721,7 +717,7 @@ WriteCheckIdentity(FILE *file, const routine_t *rt)
 	fprintf(file, "\tmsgh_simple = !(OutP->Head.msgh_bits & MACH_MSGH_BITS_COMPLEX);\n");
 	fprintf(file, "\n");
 
-	fprintf(file, "\tif (((msgh_size %s %d)",
+	fprintf(file, "\tif (mig_unlikely (((msgh_size %s %d)",
 		(rt->rtNumReplyVar > 0) ? "<" : "!=",
 		rt->rtReplySize);
 
@@ -734,7 +730,7 @@ WriteCheckIdentity(FILE *file, const routine_t *rt)
 
 	fprintf(file, "\t    ((msgh_size != sizeof(mig_reply_header_t)) ||\n");
 	fprintf(file, "\t     !msgh_simple ||\n");
-	fprintf(file, "\t     (OutP->RetCode == KERN_SUCCESS)))\n");
+	fprintf(file, "\t     (OutP->RetCode == KERN_SUCCESS))))\n");
     }
     WriteMsgError(file, rt, "MIG_TYPE_ERROR");
     fprintf(file, "#endif\t/* TypeCheck */\n");
@@ -759,10 +755,10 @@ WriteRetCodeCheck(FILE *file, const routine_t *rt)
  *  WriteRoutine for each argument in the reply message.
  *************************************************************/
 static void
-WriteTypeCheck(FILE *file, register const argument_t *arg)
+WriteTypeCheck(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *it = arg->argType;
-    register const routine_t *rt = arg->argRoutine;
+    const ipc_type_t *it = arg->argType;
+    const routine_t *rt = arg->argRoutine;
 
     fprintf(file, "#if\tTypeCheck\n");
     if (akCheck(arg->argKind, akbReplyQC))
@@ -772,7 +768,7 @@ WriteTypeCheck(FILE *file, register const argument_t *arg)
     }
     else
     {
-	fprintf(file, "\tif (");
+	fprintf(file, "\tif (mig_unlikely (");
 	if (!it->itIndefinite) {
 	    fprintf(file, "(OutP->%s%s.msgt_inline != %s) ||\n\t    ",
 		arg->argTTName,
@@ -800,7 +796,7 @@ WriteTypeCheck(FILE *file, register const argument_t *arg)
 		    arg->argTTName,
 		    arg->argLongForm ? "l" : "",
 		    it->itNumber);
-	fprintf(file, "\t    (OutP->%s.msgt%s_size != %d))\n",
+	fprintf(file, "\t    (OutP->%s.msgt%s_size != %d)))\n",
 		arg->argTTName,
 		arg->argLongForm ? "l" : "",
 		it->itSize);
@@ -811,10 +807,10 @@ WriteTypeCheck(FILE *file, register const argument_t *arg)
 }
 
 static void
-WriteCheckArgSize(FILE *file, register const argument_t *arg)
+WriteCheckArgSize(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *ptype = arg->argType;
-    register const ipc_type_t *btype = ptype->itElement;
+    const ipc_type_t *ptype = arg->argType;
+    const ipc_type_t *btype = ptype->itElement;
     const argument_t *count = arg->argCount;
     int multiplier = btype->itTypeSize / btype->itNumber;
 
@@ -826,7 +822,7 @@ WriteCheckArgSize(FILE *file, register const argument_t *arg)
 		arg->argTTName, arg->argLongForm ? ".msgtl_header" : "");
     }
 
-    if (btype->itTypeSize % 4 != 0)
+    if (btype->itTypeSize % word_size != 0)
 	fprintf(file, "(");
 
     if (multiplier > 1)
@@ -834,19 +830,19 @@ WriteCheckArgSize(FILE *file, register const argument_t *arg)
 
     fprintf(file, "OutP->%s", count->argMsgField);
 
-    /* If the base type size of the data field isn`t a multiple of 4,
+    /* If the base type size of the data field isn`t a multiple of word_size,
        we have to round up. */
-    if (btype->itTypeSize % 4 != 0)
-	fprintf(file, " + 3) & ~3");
+    if (btype->itTypeSize % word_size != 0)
+	fprintf(file, " + %d) & ~%d", word_size - 1, word_size - 1);
 
     if (ptype->itIndefinite)
 	fprintf(file, " : sizeof(%s *)", FetchUserType(btype));
 }
 
 static void
-WriteCheckMsgSize(FILE *file, register const argument_t *arg)
+WriteCheckMsgSize(FILE *file, const argument_t *arg)
 {
-    register const routine_t *rt = arg->argRoutine;
+    const routine_t *rt = arg->argRoutine;
 
     /* If there aren't any more Out args after this, then
        we can use the msgh_size_delta value directly in
@@ -855,10 +851,10 @@ WriteCheckMsgSize(FILE *file, register const argument_t *arg)
     if (arg->argReplyPos == rt->rtMaxReplyPos)
     {
 	fprintf(file, "#if\tTypeCheck\n");
-	fprintf(file, "\tif (msgh_size != %d + (",
+	fprintf(file, "\tif (mig_unlikely (msgh_size != %d + (",
 		rt->rtReplySize);
 	WriteCheckArgSize(file, arg);
-	fprintf(file, "))\n");
+	fprintf(file, ")))\n");
 
 	WriteMsgError(file, rt, "MIG_TYPE_ERROR");
 	fprintf(file, "#endif\t/* TypeCheck */\n");
@@ -872,8 +868,8 @@ WriteCheckMsgSize(FILE *file, register const argument_t *arg)
 	boolean_t LastVarArg = arg->argReplyPos+1 == rt->rtNumReplyVar;
 
 	/* calculate the actual size in bytes of the data field.  note
-	   that this quantity must be a multiple of four.  hence, if
-	   the base type size isn't a multiple of four, we have to
+	   that this quantity must be a multiple of word_size.  hence, if
+	   the base type size isn't a multiple of word_size, we have to
 	   round up.  note also that btype->itNumber must
 	   divide btype->itTypeSize (see itCalculateSizeInfo). */
 
@@ -886,10 +882,12 @@ WriteCheckMsgSize(FILE *file, register const argument_t *arg)
 	   it won't underflow. */
 
 	if (LastVarArg)
-	    fprintf(file, "\tif (msgh_size != %d + msgh_size_delta)\n",
+	    fprintf(file,
+		"\tif (mig_unlikely (msgh_size != %d + msgh_size_delta))\n",
 		rt->rtReplySize);
 	else
-	    fprintf(file, "\tif (msgh_size < %d + msgh_size_delta)\n",
+	    fprintf(file,
+		"\tif (mig_unlikely (msgh_size < %d + msgh_size_delta))\n",
 		rt->rtReplySize);
 	WriteMsgError(file, rt, "MIG_TYPE_ERROR");
 
@@ -907,10 +905,10 @@ WriteCheckMsgSize(FILE *file, register const argument_t *arg)
  *  in the reply message.
  *************************************************************/
 static void
-WriteExtractArgValue(FILE *file, register const argument_t *arg)
+WriteExtractArgValue(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t	*argType = arg->argType;
-    register const char *ref = arg->argByReferenceUser ? "*" : "";
+    const ipc_type_t	*argType = arg->argType;
+    const char *ref = arg->argByReferenceUser ? "*" : "";
 
     if (argType->itInLine && argType->itVarArray) {
 
@@ -942,9 +940,10 @@ WriteExtractArgValue(FILE *file, register const argument_t *arg)
 	    fprintf(file, "\tif (!OutP->%s%s.msgt_inline)\n",
 		    arg->argTTName,
 		    arg->argLongForm ? ".msgtl_header" : "");
-	    fprintf(file, "\t    %s%s = *((%s **)OutP->%s);\n",
+	    fprintf(file, "\t    %s%s = OutP->%s%s;\n",
 		    ref, arg->argVarName,
-		    FetchUserType(btype), arg->argMsgField);
+		    arg->argMsgField,
+		    OOLPostfix);
 	    fprintf(file, "\telse if (OutP->%s", count->argMsgField);
 	    if (btype->itNumber > 1)
 		fprintf(file, " / %d", btype->itNumber);
@@ -976,9 +975,9 @@ WriteExtractArgValue(FILE *file, register const argument_t *arg)
 	     *	after checking that number of elements doesn`t
 	     *	exceed user`s maximum.
 	     */
-	    register const argument_t *count = arg->argCount;
-	    register const char *countRef = count->argByReferenceUser ? "*" :"";
-	    register const ipc_type_t *btype = argType->itElement;
+	    const argument_t *count = arg->argCount;
+	    const char *countRef = count->argByReferenceUser ? "*" :"";
+	    const ipc_type_t *btype = argType->itElement;
 
 	    /* Note count->argMultiplier == btype->itNumber */
 
@@ -1030,9 +1029,9 @@ WriteExtractArgValue(FILE *file, register const argument_t *arg)
 }
 
 static void
-WriteExtractArg(FILE *file, register const argument_t *arg)
+WriteExtractArg(FILE *file, const argument_t *arg)
 {
-    register const routine_t *rt = arg->argRoutine;
+    const routine_t *rt = arg->argRoutine;
 
     if (akCheck(arg->argKind, akbReply))
 	WriteTypeCheck(file, arg);
@@ -1052,9 +1051,9 @@ WriteExtractArg(FILE *file, register const argument_t *arg)
 }
 
 static void
-WriteAdjustReplyMsgPtr(FILE *file, register const argument_t *arg)
+WriteAdjustReplyMsgPtr(FILE *file, const argument_t *arg)
 {
-    register const ipc_type_t *ptype = arg->argType;
+    const ipc_type_t *ptype = arg->argType;
 
     fprintf(file,
 	"\tOutP = (Reply *) ((char *) OutP + msgh_size_delta - %d);\n\n",
@@ -1062,10 +1061,10 @@ WriteAdjustReplyMsgPtr(FILE *file, register const argument_t *arg)
 }
 
 static void
-WriteReplyArgs(FILE *file, register const routine_t *rt)
+WriteReplyArgs(FILE *file, const routine_t *rt)
 {
-    register const argument_t *arg;
-    register const argument_t *lastVarArg;
+    const argument_t *arg;
+    const argument_t *lastVarArg;
 
     lastVarArg = argNULL;
     for (arg = rt->rtArgs; arg != argNULL; arg = arg->argNext) {
@@ -1118,7 +1117,7 @@ WriteReturnValue(FILE *file, const routine_t *rt)
 /*************************************************************
  *  Writes the elements of the message type declaration: the
  *  msg_type structure, the argument itself and any padding
- *  that is required to make the argument a multiple of 4 bytes.
+ *  that is required to make the argument a multiple of word_size bytes.
  *  Called by WriteRoutine for all the arguments in the request
  *  message first and then the reply message.
  *************************************************************/
@@ -1129,7 +1128,7 @@ WriteFieldDecl(FILE *file, const argument_t *arg)
 }
 
 static void
-WriteStubDecl(FILE *file, register const routine_t *rt)
+WriteStubDecl(FILE *file, const routine_t *rt)
 {
     fprintf(file, "\n");
     fprintf(file, "/* %s %s */\n", rtRoutineKindToStr(rt->rtKind), rt->rtName);
@@ -1145,7 +1144,7 @@ WriteStubDecl(FILE *file, register const routine_t *rt)
  *  WriteUser for each routine.
  *************************************************************/
 static void
-WriteRoutine(FILE *file, register const routine_t *rt)
+WriteRoutine(FILE *file, const routine_t *rt)
 {
     /* write the stub's declaration */
 
@@ -1203,12 +1202,8 @@ WriteRoutine(FILE *file, register const routine_t *rt)
 	else {
 	    WriteReplyArgs(file, rt);
 
-	    /* return the return value, if any */
-
-	    if (rt->rtProcedure)
-		fprintf(file, "\t/* Procedure - no return needed */\n");
-	    else
-		WriteReturnValue(file, rt);
+	    /* return the return value */
+            WriteReturnValue(file, rt);
 	}
     }
 
@@ -1221,7 +1216,7 @@ WriteRoutine(FILE *file, register const routine_t *rt)
 void
 WriteUser(FILE *file, const statement_t *stats)
 {
-    register const statement_t *stat;
+    const statement_t *stat;
 
     WriteProlog(file);
     for (stat = stats; stat != stNULL; stat = stat->stNext)
@@ -1249,7 +1244,7 @@ WriteUser(FILE *file, const statement_t *stats)
 void
 WriteUserIndividual(const statement_t *stats)
 {
-    register const statement_t *stat;
+    const statement_t *stat;
 
     for (stat = stats; stat != stNULL; stat = stat->stNext)
 	switch (stat->stKind)
@@ -1257,7 +1252,7 @@ WriteUserIndividual(const statement_t *stats)
 	  case skRoutine:
 	    {
 		FILE *file;
-		register char *filename;
+		char *filename;
 
 		filename = strconcat(UserFilePrefix,
 				     strconcat(stat->stRoutine->rtName, ".c"));
